@@ -44,6 +44,8 @@ try:
     from numpy import *
     from numpy.linalg import solve
 except:
+    # Initialize gettext for messages outside an inkex derived class
+    inkex.localize() 
     inkex.errormsg(_("Failed to import the numpy or numpy.linalg modules. These modules are required by this extension. Please install them and try again."))
     inkex.sys.exit()
 
